@@ -1,4 +1,4 @@
-def get_metadata(locale, user=None):
+def get_metadata(locale, user=None, request_data=None):
     if user is None:
         user = {}
     return {
@@ -7,5 +7,6 @@ def get_metadata(locale, user=None):
             "id": user.get("id", None),
             "username": user.get("username", None)
         },
+        'request_data': request_data if request_data else {},
         "transaction": []
     }
